.. _introduction:

Introduction
============

Goals
-----
*Dyndnsc* was born as a minimal module for use in the *ANGEL APP*, a p2p
filesystem on top of webdav. At the time, the command line interface was not
important. Now that time has passed, the goals are essentially to provide
both an easy to use command line tool as well as providing an OK API for
developers who want to add dyndns capabilities to their software. Also,
providing support for many different ways of detecting and updating IP/DNS
records is important.

